@@ -1,9 +1,16 @@
-/* quick3.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20160102).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -19,9 +26,9 @@ static real c_b13 = .8f;
 static integer c__37 = 37;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
-/* Main program */ MAIN__(void)
+/* Main program */ int MAIN__(void)
 {
     /* System generated locals */
     real r__1, r__2;
@@ -32,22 +39,22 @@ static integer c__37 = 37;
 	    e_wsle(void), s_rsle(cilist *), e_rsle(void);
 
     /* Local variables */
-    static real alat, alon, slat;
     static integer i__, j;
     static real p[1369]	/* was [37][37] */;
+    static integer iws;
+    static real alat, alon, slat;
     extern /* Subroutine */ int grcls_(void), grfrm_(void), gropn_(integer *),
 	     udcntr_(real *, integer *, integer *, integer *), grswnd_(real *,
 	     real *, real *, real *), grstrf_(void), usdaxs_(void), grstrn_(
 	    integer *), sgpwsn_(void), grsvpt_(real *, real *, real *, real *)
 	    ;
-    static integer iws;
 
     /* Fortran I/O blocks */
     static cilist io___7 = { 0, 6, 0, 0, 0 };
     static cilist io___8 = { 0, 5, 0, 0, 0 };
 
 
-/* -- Ĵ´ؿ ---- */
+/* -- 球面調和関数 ---- */
     for (j = 1; j <= 37; ++j) {
 	for (i__ = 1; i__ <= 37; ++i__) {
 	    alon = ((i__ - 1) * 360.f / 36 + 0.f) * .017453277777777776f;
@@ -63,7 +70,7 @@ static integer c__37 = 37;
 	}
 /* L20: */
     }
-/* --  ---- */
+/* -- グラフ ---- */
     s_wsle(&io___7);
     do_lio(&c__9, &c__1, " WORKSTATION ID (I)  ? ;", (ftnlen)24);
     e_wsle();
